@@ -1,13 +1,10 @@
-package Carp::Notify;
-{
-  $Carp::Notify::VERSION = '1.11';
-}
-
-# ABSTRACT: Loudly complain in lots of places when things break badly
-
-use 5.005; # probably lower, but I haven't tested it below 005
+use 5.005;
 use strict;
-local $^W = 1;
+use warnings;
+
+package Carp::Notify;
+$Carp::Notify::VERSION = '1.12';
+# ABSTRACT: Loudly complain in lots of places when things break badly
 
 my %def = (
     "smtp"   => 'your.smtp.com', # IMPORTANT!  Set this!  I mean it!
@@ -56,17 +53,9 @@ eoE
 
 my $settables = "(?:" . join('|', keys %def) . ')';
 
-BEGIN {
-    $Carp::Notify::can_email = 1;
-    eval "use Socket";
-    $Carp::Notify::can_email = 0 if $@;
-
-    $Carp::Notify::fatal = 1; # doesn't really belong here, but it's the cleanest place to put it...
-};
-
+$Carp::Notify::fatal = 1;
 
 {
-    no strict 'refs';
     my $calling_package = undef;
 
     my %storable_vars = ();
@@ -75,6 +64,8 @@ BEGIN {
     my %init = ();
 
     sub import {
+        # this wants rework, badly
+        no strict 'refs';
         my ($package, $file, $line) = caller;
         $calling_package = $package;
 
@@ -102,11 +93,15 @@ BEGIN {
     };
 
     sub store_vars {
+        # this wants rework
+        no strict 'refs';
+
         my $stored_vars = "";
         my $calling_package = (caller(1))[0]; # eek!  This may not always work
 
         foreach my $storable_var (@{$storable_vars{$calling_package}}){
-            my $type = $1 if $storable_var =~ s/([\$@%&])//;
+            my $type = '';
+            $type = $1 if $storable_var =~ s/([\$@%&])//;
 
             my $package = $calling_package . "::";
             $package = $1 if $storable_var =~ s/(.+::)//;
@@ -170,9 +165,11 @@ BEGIN {
 
         %init = (%def, %init);
 
-        my $stored_vars = store_vars()  if $init{'store_vars'};
-        my $stack       = stack_trace() if $init{'stack_trace'};
-        my $environment = store_env()   if $init{'store_env'};
+        my( $stored_vars, $stack, $environment ) = ( '', '', '' );
+
+        $stored_vars = store_vars()  if $init{'store_vars'};
+        $stack       = stack_trace() if $init{'stack_trace'};
+        $environment = store_env()   if $init{'store_env'};
 
         my $message = "";
 
@@ -218,6 +215,7 @@ BEGIN {
                     $init{'death_function'}->(%init, 'errors' => $errors);
                 }
                 else {
+                    # this wants rework, badly
                     no strict 'vars';
                     my ($calling_package) = (caller)[0];
                     my $package = $calling_package . "::";
@@ -241,7 +239,7 @@ BEGIN {
         }
         else {
             $Carp::Notify::fatal = 1;
-            return undef;
+            return;
         };
     };
 };
@@ -281,6 +279,7 @@ sub log_it {
     my $message  = $init{message};
 
     local *LOG;
+
     my %pairs = (
         "log_notify"  => "notify_log",
         "log_explode" => "explode_log",
@@ -303,7 +302,8 @@ sub log_it {
 sub simple_smtp_mailer {
     my %init = @_;
     my $message = $init{"message"};
-    error($init{'error_function'},"Cannot email: Socket.pm could not load!") unless $Carp::Notify::can_email;
+
+    use Socket;
 
     local *MAIL;
     my $response = undef;
@@ -385,7 +385,7 @@ sub today {
     ($diffhour = sprintf("%03d", $diffhour)) =~ s/^0/\+/;
 
     return sprintf("%s, %02d %s %04d %02d:%02d:%02d %05s",
-        $days[$wday], $mday, $months[$mon], $year + 1900, $hour, $min, $sec, $diffhour . sprintf("%02d", $min - $gmin));
+        $days[$wday], $mday, $months[$mon], $year, $hour, $min, $sec, $diffhour . sprintf("%02d", $min - $gmin));
 };
 
 # error does nothing unless you specify the error_function, in that case it's called with the error provided.
@@ -395,13 +395,16 @@ sub error {
         $func->($error);
     }
     elsif ($func){
+        # this wants reworked
         no strict 'refs';
         my ($calling_package) = (caller)[0];
         my $package = $calling_package . "::";
         $package = $1 if $$func =~ s/(.+::)//;
         &{$package . $func}($error);
     }
-    else {undef};
+    else {
+        return;
+    };
 };
 
 
@@ -411,13 +414,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Carp::Notify - Loudly complain in lots of places when things break badly
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -833,6 +838,24 @@ way that an explode would.
 
 =back
 
+=head1 Internal functions
+
+=over 11
+
+=item error
+
+Used to proxy to the registered error_function, if any.
+
+=item today
+
+Used to for standard formatting of the date.
+
+=item simple_smtp_mailer
+
+Used to speak to an SMTP server.
+
+=back
+
 =head1 FAQ
 
 B<So what's the point of this thing?>
@@ -905,7 +928,11 @@ store_vars destroys the contents of the stored variables, making multiple notifi
 store_vars doesn't gracefully handle being called directly from the main script (i.e. it expects there to be at least one other function
 in the call stack).
 
-today returns a year 1900 too high.  See L<https://rt.cpan.org/Ticket/Display.html?id=8124>.
+The internal function today doesn't always report GMT offsets for some timezones that don't use whole hours
+(e.g. Indian/Cocos aka CCT, which is sometimes reported as +07-30 instead of +0630).
+
+The internal function today has an edge condition where the GMT offset could report one additional or one less
+minute of offset (rare).
 
 B<Could I see some more examples?>
 
@@ -946,6 +973,20 @@ Why yes, yes it was.
 
 =over 11
 
+v1.12 - Mar 31, 2016 -
+
+* Fix tests relying on hash ordering
+
+* fix double adding of 1900 to year in calculations
+
+* minor cleanups for Test::Perl::Critic and Test::Pod::Coverage
+
+* eliminate conditional 'my' statements
+
+v1.11 - Feb 1, 2013 -
+
+* Updated documentation and maintainership.
+
 v1.10 - April 13, 2001 -
 
 * Long overdue re-write/enhancements.
@@ -989,7 +1030,7 @@ Jim Thomason <thomasoniii@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Brian Conry, and 2000, 2001 by Jim Thomason.
+This software is copyright (c) 2016 by Brian Conry, and 2000, 2001 by Jim Thomason.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -1033,7 +1074,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Carp-Notify>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Notify>
 
 =item *
 
@@ -1065,7 +1106,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Carp-Notify>
+L<http://cpants.cpanauthors.org/dist/Carp-Notify>
 
 =item *
 
@@ -1096,7 +1137,7 @@ L<http://deps.cpantesters.org/?module=Carp::Notify>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-carp-notify at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Carp-Notify>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Carp-Notify>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
